=================
 catleg |version|
=================

*A library of helper tools for catala programming in the context of French legislative texts.*

|PyPI| |CI| |License|

.. |PyPI| image:: https://img.shields.io/pypi/v/catleg.svg
   :target: https://pypi.org/project/catleg/
.. |CI| image:: https://github.com/CatalaLang/catleg/workflows/check/badge.svg
   :target: https://github.com/CatalaLang/catleg/actions
.. |License| image:: https://img.shields.io/badge/license-Apache%202.0-blue.svg
   :target: https://github.com/CatalaLang/catleg/blob/main/LICENSE

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   installation
   cli_reference.md


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
